{ nix-flatpak, lib, pkgs, ... }:
{
  nixpkgs.config.allowUnfree = true;
  
  home = {
    packages = with pkgs; [
      gnupg
      eza
      just
      fd
      fzf
      bat
      jq
      yt-dlp
      htop
      ripgrep
      erdtree
      age
      figlet
      ffmpeg
      rlwrap
      pinentry
      unrar
      unzip
      zip
      htop
      opendrop
      owl 
      pass
      dconf

      mesa      
      usbutils
      pciutils
      util-linux
      coreutils
      libgcc
      raylib
      SDL2
      protonplus

      ruby
      janet
      jpm
      python3
      python311Packages.pip
      sbcl
      nodejs_18
      platformio-core
      real_time_config_quick_scan

      borgmatic
      kanata-with-cmd
      wezterm 
      lazygit
      nnn
      jetbrains-mono

      fishPlugins.foreign-env
      fishPlugins.z
      fishPlugins.fzf
      fishPlugins.bass
      fishPlugins.autopair

      via
      bitwarden-cli
      bitwarden-desktop
      rbw
      tailscale
      protonplus

      gnomeExtensions.just-perfection
      gnomeExtensions.dash-to-dock
      gnomeExtensions.pano
      gnome-software
      gnome-tweaks
      colloid-gtk-theme
      colloid-icon-theme
      whitesur-gtk-theme
      whitesur-cursors
      whitesur-icon-theme
      graphite-gtk-theme
      graphite-cursors
      papers
      newsflash

      librewolf
      ungoogled-chromium
      obsidian
      vlc
      polychromatic
      discord
      slack
      signal-desktop
      libreoffice
      plexamp
      audacity
      supercollider-with-plugins
      bitwig-studio
      blender
      davinci-resolve-studio
      steam
      zotero_7
      handbrake
      renoise
    ];

    username = "emenel";
    homeDirectory = "/home/emenel";

    sessionPath = [ "/home/emenel/.config/emacs/bin" ];

    stateVersion = "24.05";
  };

  programs = {
    home-manager.enable = true;
    direnv = {
      enable = true;
      #enableFishIntegration = true; # see note on other shells below
      nix-direnv.enable = true;
    };
    fish = {
      enable = true;
      #vendor = {
      #  completions.enable = true;
      #  config.enable = true;
      #  functions.enable = true;
      #};
    };
    starship = {
      enable = true;
      enableFishIntegration = true;
    };
    mu.enable = true;
    mbsync.enable = true;
    msmtp.enable = true;
    emacs = {
      enable = true;
      package = pkgs.emacs;
      extraPackages = epkgs: [
        epkgs.mu4e
        epkgs.vterm
      ];
    };
  };

  dconf.settings = {
    "org/gnome/desktop/wm/keybindings" = {
      shift-overview-up = "";
      shift-overview-down = "";
    };
  };

  nixpkgs.config.packageOverrides = pkgs: {
    renoise = pkgs.renoise.override {
      releasePath = /home/emenel/temp/rns_344_linux_x86_64.tar.gz;
    };
  };

  services = {
    flatpak.enable = true;
    #tailscale.enable = true;

    #mbsync.configFile = ../dotfiles/dot_config/isyncrc;
  };

  xdg.systemDirs.data = [
    "/home/emenel/.local/share/applications/wine/Programs"
    "/home/emenel/.local/share/applications"
    "/var/lib/flatpak/exports/share"
    "/home/emenel/.local/share/flatpak/exports/share"
    "/home/emenel/.nix-profile/share/applications"
  ];

  services.flatpak.packages = [
    "io.github.zen_browser.zen"
    "com.github.johnfactotum.QuickLookup"
  ];

  xdg.configFile."kmonad".source = ../dotfiles/dot_config/kmonad;

  xdg.configFile."starship.toml".source = ../dotfiles/dot_config/starship.toml;
  xdg.configFile."wezterm".source = ../dotfiles/dot_config/wezterm;

  xdg.configFile."fish/functions" = {
    source = ../dotfiles/dot_config/fish/functions;
    recursive = true;
  };

  xdg.configFile."emacs".enable = false;
  home.file.".msmtprc".source = ../dotfiles/dot_msmtprc;
  home.file.".mbsyncrc".source = ../dotfiles/dot_mbsyncrc;
}
